@@ -3,9 +3,11 @@
 from .base import DocstringConverter
 from .google import GoogleDocstringConverter
 from .numpydoc import NumpydocDocstringConverter
+from .stub import StubDocstringConverter
 
 __all__ = [
     'DocstringConverter',
     'GoogleDocstringConverter',
     'NumpydocDocstringConverter',
+    'StubDocstringConverter',
 ]
